#include "InstallerTypes.r"

//  This Split File Copy Script is to demonstate how one can have the Installer
//  build the target file from multiple source files.  In this example the Read Me
//  file has been split into 6 different source files, 3 for each fork.  In addition
//  the resource fork source data is located in the data fork to avoid problems
//  with an incomplete resource fork.

//  Please take note that the target part sizes in the source parts list MUST be
//  exact and in the order they are to be built in.  For this example, the source
//  disk order has been reversed to demonstate the flexibiliity of the Installer
//  in assembling the target file together.


resource 'inpk' (100) {
	format0 {
		showsOnCustom,
		removable,
		dontForceRestart,
		0,
		0,
		"Copy File Read Me from split source files....",
		{	'infa', 1000,
			'infa', 2000	},
		}
	};

resource 'infa' (1000) {
	format1 {
		deleteWhenRemoving,
		deleteWhenInstalling,
		copy,
		dontIgnoreLockedFile,
		dontSetFileLocked,
		useVersProcToCompare,
		srcNeedExist,
		rsrcForkInRsrcFork,
		leaveAloneIfNewer,
		updateExisting,
		copyIfNewOrUpdate,
		noRsrcFork,
		dataFork,					//  only copy the data fork here.
		0,
		0x0,
		10000,
		{	21001, 0, 0,			//  parts list, with exact target part sizes.
			21002, 0, 0,
			21003, 0, 0	},
		0x0,
		0,
		0,
		"Read Me - data fork"
		}
	};

resource 'infa' (2000) {
	format1 {
		deleteWhenRemoving,
		deleteWhenInstalling,
		copy,
		dontIgnoreLockedFile,
		dontSetFileLocked,
		useVersProcToCompare,
		srcNeedExist,
		rsrcForkInDataFork,
		leaveAloneIfNewer,
		updateExisting,
		copyIfNewOrUpdate,
		rsrcFork,					//  only copy the resource fork here.
		noDataFork,
		0,
		0x0,
		10000,
		{	22001, 0, 0,			//  parts list, with exact target part sizes.
			22002, 0, 0,
			22003, 0, 0	},
		0x0,
		0,
		0,
		"Read Me - resource fork"
		}
	};

resource 'infs' (10000) {
	'ttro',
	'ttxt',
	0x0,
	noSearchForFile,
	TypeCrMustMatch,
	":Read Me"
	};

resource 'infs' (21001) {
	'TEXT',
	'MPS ',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Source Disk 1:Read Me.dataFork1"
	};

resource 'infs' (21002) {
	'TEXT',
	'MPS ',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Source Disk 2:Read Me.dataFork2"
	};

resource 'infs' (21003) {
	'TEXT',
	'MPS ',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Source Disk 3:Read Me.dataFork3"
	};

resource 'infs' (22001) {
	'TEXT',
	'MPS ',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Source Disk 4:Read Me.rsrcFork1"
	};

resource 'infs' (22002) {
	'TEXT',
	'MPS ',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Source Disk 5:Read Me.rsrcFork2"
	};

resource 'infs' (22003) {
	'TEXT',
	'MPS ',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Source Disk 6:Read Me.rsrcFork3"
	};
	
resource 'indo' (1) {
	format1 {{
		kExpectFloppyDisk, "Source Disk 6",
		kExpectFloppyDisk, "Source Disk 5",
		kExpectFloppyDisk, "Source Disk 4",
		kExpectFloppyDisk, "Source Disk 3",
		kExpectFloppyDisk, "Source Disk 2",
		kExpectFloppyDisk, "Source Disk 1",
		}}
	};
