#include "InstallerTypes.r"

//  The "creation date compare" is set up to use the standard old way of determining
//  whether or not to replace/update an existing file from the creation date.
//  This is the recommended way of updating files which do not have any version
//  information within the file.

//  If the correct flags are set, Installer will compare the creation date of
//  the existing target file with the creation date hard-coded in the 'infs'
//  of the source file.  (Be sure that the 'incd' contains the creation date
//  of the Install Script, in case the Finder readjusts the source file's 
//  creation date.

//  The following flags must be set:
//		copy, useSrcCrDateToCompare, leaveAloneIfNewer, & update existing.
//  also the 'infs' for the source file must have the creation date hard coded.




//  The "default version compare" is set up to use the standard new way of
//  determining whether or not to replace/update an existing file from the
//  file's 'vers' 1 resource. This is the recommended way of determining whether
//  or not to update an existing file.

//  If the correct flags are set, Installer will compare the 'vers' 1 resource
//  the existing target file with the version hard-coded in the 'infa'
//  of the source file.

//  The following flags must be set:
//		copy, useSrcCrDateToCompare, leaveAloneIfNewer, & update existing.
//  also the 'infa' must have the source version hard-coded in BCD format.




resource 'inpk' (100) {
	format0 {
		showsOnCustom,
		removable,
		dontForceRestart,
		0,
		0,
		"Copy File Read Me with old creation date compare....",
		{	'infa', 1000	},
		}
	};

resource 'inpk' (200) {
	format0 {
		showsOnCustom,
		removable,
		dontForceRestart,
		0,
		0,
		"Copy File TeachText with default version compare....",
		{	'infa', 2000	},
		}
	};

resource 'infa' (1000) {
	format1 {
		deleteWhenRemoving,
		deleteWhenInstalling,
		copy,							//  Copy on Install
		dontIgnoreLockedFile,
		dontSetFileLocked,
		useSrcCrDateToCompare,			//  Use creation date for compare
		srcNeedExist,
		rsrcForkInRsrcFork,
		leaveAloneIfNewer,				//  Do not update a newer file
		updateExisting,					//  Update an existing file
		copyIfNewOrUpdate,
		rsrcFork,
		dataFork,
		0,
		0x0,
		10000,
		{	20000, 0, 0	},
		0x0,
		0,
		0,
		"Read Me"
		}
	};

resource 'infa' (2000) {
	format1 {
		deleteWhenRemoving,
		deleteWhenInstalling,
		copy,							//  Copy on Install
		dontIgnoreLockedFile,
		dontSetFileLocked,
		useVersProcToCompare,			//  Use creation date for compare
		srcNeedExist,
		rsrcForkInRsrcFork,
		leaveAloneIfNewer,				//  Do not update a newer file
		updateExisting,					//  Update an existing file
		copyIfNewOrUpdate,
		rsrcFork,
		dataFork,
		0,
		0x0,
		30000,
		{	31000, 0, 0	},
		0,								//  The source version number in BCD format
		0,								//  MUST be zero to use default version compare
		0,
		"TeachText"
		}
	};

resource 'infs' (10000) {
	'ttro',
	'ttxt',
	0x0,
	noSearchForFile,
	TypeCrMustMatch,
	":Read Me"
	};

resource 'infs' (20000) {
	'ttro',
	'ttxt',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Tidbits:Apple Utilities:Read Me"	//  System 7.1 Tidbits FDHD diskette
	};




resource 'infs' (30000) {
	'APPL',
	'ttxt',
	0x0,
	noSearchForFile,
	TypeCrMustMatch,
	":TeachText"
	};

resource 'infs' (31000) {
	'APPL',
	'ttxt',
	0x1,
	noSearchForFile,
	TypeCrMustMatch,
	"Tidbits:Apple Utilities:TeachText"	//  System 7.1 Tidbits FDHD diskette
	};
